@@ -172,7 +172,7 @@ class RestRequestHandler(tornado.web.RequestHandler):
 
     def write(self, chunk):
         if isinstance(chunk, (dict, list)):
-            chunk = self.dump_response(chunk)
+            chunk = self.encode_body(chunk)
             self.set_header("Content-Type", "application/json; charset=UTF-8")
         super(RestRequestHandler, self).write(chunk)
 
@@ -197,6 +197,7 @@ class RestRequestHandler(tornado.web.RequestHandler):
             if self.request.method in ('PUT', 'POST', 'PATCH'):
                 self._load_json_body()
             self.check_arguments()
+            self.check_authenticated()
             method = getattr(self, self.request.method.lower())
             method = tornado.gen.coroutine(method)
             chunk = yield method(*self.path_args, **self.path_kwargs)
@@ -214,7 +215,7 @@ class RestRequestHandler(tornado.web.RequestHandler):
 
     def _load_json_body(self):
         try:
-            json_body = json.loads(self.request.body)
+            json_body = self.decode_body(self.request.body)
             if not isinstance(json_body, (dict, list)):
                 raise TypeError
             self.request.json_body = json_body
@@ -233,9 +234,17 @@ class RestRequestHandler(tornado.web.RequestHandler):
         if not self._finished:
             self._when_complete(self._wrap_method(), self._execute_finish)
 
-    def dump_response(self, chunk):
-        """默认使用JSON序列化
-        :param chunk:
-        :return:
+    def check_authenticated(self):
+        """Overrided by subclass, default do nothing
         """
-        return json.dumps(chunk, ensure_ascii=False)
\ No newline at end of file
+        pass
+
+    def encode_body(self, body):
+        """默认使用JSON序列化
+        """
+        return json.dumps(body)
+
+    def decode_body(self, body):
+        """默认使用JSON反序列化
+        """
+        return json.loads(body)
\ No newline at end of file
